LocalizationState class

Constructors

LocalizationState(Locale currentLocale, Map<String, Map<String, String>> translations)

Properties

currentLocale → Locale
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translations → Map<String, Map<String, String>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
translate(String key) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited